@@ -135,7 +135,7 @@ void pa_cpu_get_arm_flags(pa_cpu_arm_flag_t *flags) {
 #endif
 }
 
-pa_bool_t pa_cpu_init_arm(pa_cpu_arm_flag_t *flags) {
+bool pa_cpu_init_arm(pa_cpu_arm_flag_t *flags) {
 #if defined (__arm__)
 #if defined (__linux__)
     pa_cpu_get_arm_flags(flags);
@@ -149,13 +149,13 @@ pa_bool_t pa_cpu_init_arm(pa_cpu_arm_flag_t *flags) {
     }
 #endif
 
-    return TRUE;
+    return true;
 
 #else /* defined (__linux__) */
     pa_log("Reading ARM CPU features not yet supported on this OS");
 #endif /* defined (__linux__) */
 
 #else /* defined (__arm__) */
-    return FALSE;
+    return false;
 #endif /* defined (__arm__) */
 }
