@@ -102,7 +102,7 @@ static char *segment_name(char *fn, size_t l, unsigned id) {
 }
 #endif
 
-int pa_shm_create_rw(pa_shm *m, size_t size, pa_bool_t shared, mode_t mode) {
+int pa_shm_create_rw(pa_shm *m, size_t size, bool shared, mode_t mode) {
 #ifdef HAVE_SHM_OPEN
     char fn[32];
     int fd = -1;
@@ -143,7 +143,7 @@ int pa_shm_create_rw(pa_shm *m, size_t size, pa_bool_t shared, mode_t mode) {
         m->ptr = pa_xmalloc(m->size);
 #endif
 
-        m->do_unlink = FALSE;
+        m->do_unlink = false;
 
     } else {
 #ifdef HAVE_SHM_OPEN
@@ -180,7 +180,7 @@ int pa_shm_create_rw(pa_shm *m, size_t size, pa_bool_t shared, mode_t mode) {
         pa_atomic_store(&marker->marker, SHM_MARKER);
 
         pa_assert_se(pa_close(fd) == 0);
-        m->do_unlink = TRUE;
+        m->do_unlink = true;
 #else
         goto fail;
 #endif
@@ -324,8 +324,8 @@ int pa_shm_attach_ro(pa_shm *m, unsigned id) {
         goto fail;
     }
 
-    m->do_unlink = FALSE;
-    m->shared = TRUE;
+    m->do_unlink = false;
+    m->shared = true;
 
     pa_assert_se(pa_close(fd) == 0);
 
