@@ -45,7 +45,7 @@ typedef enum pa_sink_input_state {
     /* FIXME: we need a state for MOVING here */
 } pa_sink_input_state_t;
 
-static inline pa_bool_t PA_SINK_INPUT_IS_LINKED(pa_sink_input_state_t x) {
+static inline bool PA_SINK_INPUT_IS_LINKED(pa_sink_input_state_t x) {
     return x == PA_SINK_INPUT_DRAINED || x == PA_SINK_INPUT_RUNNING || x == PA_SINK_INPUT_CORKED;
 }
 
@@ -114,15 +114,15 @@ struct pa_sink_input {
     pa_cvolume volume_factor_sink; /* A second volume factor in format of the sink this stream is connected to. */
     pa_hashmap *volume_factor_sink_items;
 
-    pa_bool_t volume_writable:1;
+    bool volume_writable:1;
 
-    pa_bool_t muted:1;
+    bool muted:1;
 
-    /* if TRUE then the sink we are connected to and/or the volume
+    /* if true then the sink we are connected to and/or the volume
      * set is worth remembering, i.e. was explicitly chosen by the
      * user and not automatically. module-stream-restore looks for
      * this.*/
-    pa_bool_t save_sink:1, save_volume:1, save_muted:1;
+    bool save_sink:1, save_volume:1, save_muted:1;
 
     pa_resample_method_t requested_resample_method, actual_resample_method;
 
@@ -179,11 +179,11 @@ struct pa_sink_input {
 
     /* If non-NULL called whenever the sink this input is attached
      * to suspends or resumes. Called from main context */
-    void (*suspend) (pa_sink_input *i, pa_bool_t b);   /* may be NULL */
+    void (*suspend) (pa_sink_input *i, bool b);   /* may be NULL */
 
     /* If non-NULL called whenever the sink this input is attached
      * to suspends or resumes. Called from IO context */
-    void (*suspend_within_thread) (pa_sink_input *i, pa_bool_t b);   /* may be NULL */
+    void (*suspend_within_thread) (pa_sink_input *i, bool b);   /* may be NULL */
 
     /* If non-NULL called whenever the sink input is moved to a new
      * sink. Called from main context after the sink input has been
@@ -208,9 +208,9 @@ struct pa_sink_input {
     void (*state_change) (pa_sink_input *i, pa_sink_input_state_t state); /* may be NULL */
 
     /* If non-NULL this function is called before this sink input is
-     * move to a sink and if it returns FALSE the move will not
+     * move to a sink and if it returns false the move will not
      * be allowed */
-    pa_bool_t (*may_move_to) (pa_sink_input *i, pa_sink *s); /* may be NULL */
+    bool (*may_move_to) (pa_sink_input *i, pa_sink *s); /* may be NULL */
 
     /* If non-NULL this function is used to dispatch asynchronous
      * control events. Called from main context. */
@@ -229,12 +229,12 @@ struct pa_sink_input {
         pa_atomic_t drained;
 
         pa_cvolume soft_volume;
-        pa_bool_t muted:1;
+        bool muted:1;
 
-        pa_bool_t attached:1; /* True only between ->attach() and ->detach() calls */
+        bool attached:1; /* True only between ->attach() and ->detach() calls */
 
         /* rewrite_nbytes: 0: rewrite nothing, (size_t) -1: rewrite everything, otherwise how many bytes to rewrite */
-        pa_bool_t rewrite_flush:1, dont_rewind_render:1;
+        bool rewrite_flush:1, dont_rewind_render:1;
         size_t rewrite_nbytes;
         uint64_t underrun_for, playing_for;
         uint64_t underrun_for_sink; /* Like underrun_for, but in sink sample spec */
@@ -300,32 +300,32 @@ typedef struct pa_sink_input_new_data {
     pa_idxset *nego_formats;
 
     pa_cvolume volume;
-    pa_bool_t muted:1;
+    bool muted:1;
     pa_hashmap *volume_factor_items, *volume_factor_sink_items;
 
-    pa_bool_t sample_spec_is_set:1;
-    pa_bool_t channel_map_is_set:1;
+    bool sample_spec_is_set:1;
+    bool channel_map_is_set:1;
 
-    pa_bool_t volume_is_set:1;
-    pa_bool_t muted_is_set:1;
+    bool volume_is_set:1;
+    bool muted_is_set:1;
 
-    pa_bool_t volume_is_absolute:1;
+    bool volume_is_absolute:1;
 
-    pa_bool_t volume_writable:1;
+    bool volume_writable:1;
 
-    pa_bool_t save_sink:1, save_volume:1, save_muted:1;
+    bool save_sink:1, save_volume:1, save_muted:1;
 } pa_sink_input_new_data;
 
 pa_sink_input_new_data* pa_sink_input_new_data_init(pa_sink_input_new_data *data);
 void pa_sink_input_new_data_set_sample_spec(pa_sink_input_new_data *data, const pa_sample_spec *spec);
 void pa_sink_input_new_data_set_channel_map(pa_sink_input_new_data *data, const pa_channel_map *map);
-pa_bool_t pa_sink_input_new_data_is_passthrough(pa_sink_input_new_data *data);
+bool pa_sink_input_new_data_is_passthrough(pa_sink_input_new_data *data);
 void pa_sink_input_new_data_set_volume(pa_sink_input_new_data *data, const pa_cvolume *volume);
 void pa_sink_input_new_data_add_volume_factor(pa_sink_input_new_data *data, const char *key, const pa_cvolume *volume_factor);
 void pa_sink_input_new_data_add_volume_factor_sink(pa_sink_input_new_data *data, const char *key, const pa_cvolume *volume_factor);
-void pa_sink_input_new_data_set_muted(pa_sink_input_new_data *data, pa_bool_t mute);
-pa_bool_t pa_sink_input_new_data_set_sink(pa_sink_input_new_data *data, pa_sink *s, pa_bool_t save);
-pa_bool_t pa_sink_input_new_data_set_formats(pa_sink_input_new_data *data, pa_idxset *formats);
+void pa_sink_input_new_data_set_muted(pa_sink_input_new_data *data, bool mute);
+bool pa_sink_input_new_data_set_sink(pa_sink_input_new_data *data, pa_sink *s, bool save);
+bool pa_sink_input_new_data_set_formats(pa_sink_input_new_data *data, pa_idxset *formats);
 void pa_sink_input_new_data_done(pa_sink_input_new_data *data);
 
 /* To be called by the implementing module only */
@@ -349,9 +349,9 @@ fully -- or at all. If the request for a rewrite was successful, the
 sink driver will call ->rewind() and pass the number of bytes that
 could be rewound in the HW device. This functionality is required for
 implementing the "zero latency" write-through functionality. */
-void pa_sink_input_request_rewind(pa_sink_input *i, size_t nbytes, pa_bool_t rewrite, pa_bool_t flush, pa_bool_t dont_rewind_render);
+void pa_sink_input_request_rewind(pa_sink_input *i, size_t nbytes, bool rewrite, bool flush, bool dont_rewind_render);
 
-void pa_sink_input_cork(pa_sink_input *i, pa_bool_t b);
+void pa_sink_input_cork(pa_sink_input *i, bool b);
 
 int pa_sink_input_set_rate(pa_sink_input *i, uint32_t rate);
 int pa_sink_input_update_rate(pa_sink_input *i);
@@ -367,15 +367,15 @@ void pa_sink_input_kill(pa_sink_input*i);
 
 pa_usec_t pa_sink_input_get_latency(pa_sink_input *i, pa_usec_t *sink_latency);
 
-pa_bool_t pa_sink_input_is_passthrough(pa_sink_input *i);
-pa_bool_t pa_sink_input_is_volume_readable(pa_sink_input *i);
-void pa_sink_input_set_volume(pa_sink_input *i, const pa_cvolume *volume, pa_bool_t save, pa_bool_t absolute);
+bool pa_sink_input_is_passthrough(pa_sink_input *i);
+bool pa_sink_input_is_volume_readable(pa_sink_input *i);
+void pa_sink_input_set_volume(pa_sink_input *i, const pa_cvolume *volume, bool save, bool absolute);
 void pa_sink_input_add_volume_factor(pa_sink_input *i, const char *key, const pa_cvolume *volume_factor);
-void pa_sink_input_remove_volume_factor(pa_sink_input *i, const char *key);
-pa_cvolume *pa_sink_input_get_volume(pa_sink_input *i, pa_cvolume *volume, pa_bool_t absolute);
+int pa_sink_input_remove_volume_factor(pa_sink_input *i, const char *key);
+pa_cvolume *pa_sink_input_get_volume(pa_sink_input *i, pa_cvolume *volume, bool absolute);
 
-void pa_sink_input_set_mute(pa_sink_input *i, pa_bool_t mute, pa_bool_t save);
-pa_bool_t pa_sink_input_get_mute(pa_sink_input *i);
+void pa_sink_input_set_mute(pa_sink_input *i, bool mute, bool save);
+bool pa_sink_input_get_mute(pa_sink_input *i);
 
 void pa_sink_input_update_proplist(pa_sink_input *i, pa_update_mode_t mode, pa_proplist *p);
 
@@ -383,15 +383,15 @@ pa_resample_method_t pa_sink_input_get_resample_method(pa_sink_input *i);
 
 void pa_sink_input_send_event(pa_sink_input *i, const char *name, pa_proplist *data);
 
-int pa_sink_input_move_to(pa_sink_input *i, pa_sink *dest, pa_bool_t save);
-pa_bool_t pa_sink_input_may_move(pa_sink_input *i); /* may this sink input move at all? */
-pa_bool_t pa_sink_input_may_move_to(pa_sink_input *i, pa_sink *dest); /* may this sink input move to this sink? */
+int pa_sink_input_move_to(pa_sink_input *i, pa_sink *dest, bool save);
+bool pa_sink_input_may_move(pa_sink_input *i); /* may this sink input move at all? */
+bool pa_sink_input_may_move_to(pa_sink_input *i, pa_sink *dest); /* may this sink input move to this sink? */
 
 /* The same as pa_sink_input_move_to() but in two separate steps,
  * first the detaching from the old sink, then the attaching to the
  * new sink */
 int pa_sink_input_start_move(pa_sink_input *i);
-int pa_sink_input_finish_move(pa_sink_input *i, pa_sink *dest, pa_bool_t save);
+int pa_sink_input_finish_move(pa_sink_input *i, pa_sink *dest, bool save);
 void pa_sink_input_fail_move(pa_sink_input *i);
 
 pa_sink_input_state_t pa_sink_input_get_state(pa_sink_input *i);
@@ -412,10 +412,9 @@ int pa_sink_input_process_msg(pa_msgobject *o, int code, void *userdata, int64_t
 
 pa_usec_t pa_sink_input_set_requested_latency_within_thread(pa_sink_input *i, pa_usec_t usec);
 
-pa_bool_t pa_sink_input_safe_to_remove(pa_sink_input *i);
+bool pa_sink_input_safe_to_remove(pa_sink_input *i);
 bool pa_sink_input_process_underrun(pa_sink_input *i);
 
-
 pa_memchunk* pa_sink_input_get_silence(pa_sink_input *i, pa_memchunk *ret);
 
 #define pa_sink_input_assert_io_context(s) \
